#!/usr/bin/env bash

# ban only foreign IP addresses and
# add local (choosed country) to the ignore list of the jail
# notify admin of banned IP with log lines and whois output
#
# Fabian Wenk <fabian@wenks.ch>
# 21-Nov-2013	Initial publication
# 28-Nov-2013	Adapted for bsd-ipfw
# 02-Dec-2013	reworked

# check if needed options are given
if [ "${4}" = "" ]; then
	echo " Error: use ${0} <jail> <table> <ip> <logpath> <country> <action>"
	exit 1
else
	if [ ! -f ${4} ]; then
		echo " Error: file ${4} does not exist"
		exit 1
	else
		JAIL=${1}
		TABLE=${2}
		IP=${3}
		LOGPATH=${4}
		if [ "${5}" = "" ]; then
			echo " Error: <country> not set, use ISO country code for source IP to ignore"
			exit 1
		else
			COUNTRY="`echo ${5} | tr '[:lower:]' '[:upper:]'`"
		fi
		if [ "${6}" = "" ]; then
			echo " Error: <action> not set, use 'ban' or 'unban'."
			exit 1
		else
			ACTION="${6}"
		fi
	fi
fi

# Define variables
# Commands to ban / unban foreign IP addresses
ACTIONBAN="ipfw table ${TABLE} add ${IP}"
ACTIONUNBAN="ipfw table ${TABLE} delete ${IP}"

# function for reporting to admin
WHOIS="`whois ${IP}`"
CURRENTCOUNTRY="`echo "${WHOIS}" | grep ^country: | awk '{ print $2 }' | tr '[:lower:]' '[:upper:]' | uniq`"
if [ "${ACTION}" = "ban" ]; then
	if [ ! "${CURRENTCOUNTRY}" = "${COUNTRY}" ]; then
		${ACTIONBAN}
		echo "IP address banned:"
		echo "=================="
	else
		echo "IP address not banned, added to ignorelist:"
		echo "==========================================="
	fi
	echo
	echo "Affected IP address: ${IP}"
	echo "Affected Country:    ${CURRENTCOUNTRY}"
	if [ "${CURRENTCOUNTRY}" = "${COUNTRY}" ]; then
		echo
		fail2ban-client set ${JAIL} addignoreip ${IP}
		echo
		echo "To manually ban this IP address, until the fail2ban-server is restarted, use:"
		echo "  ${ACTIONBAN}"
	fi
	echo
	echo
	echo "Entries from log file:"
	echo "----------------------"
	grep ${IP} ${LOGPATH}
	echo
	echo
	echo "whois output:"
	echo "-------------"
	echo "${WHOIS}"
else
	if [ ! "${CURRENTCOUNTRY}" = "${COUNTRY}" ]; then
		${ACTIONUNBAN}
	fi
fi
exit 0
